pub type Positions<'a> = Slice<'a, [f32; 4]>;Expand description
Alias for a strided slice of positions.
Positions do not need to be strided, but the API accepts a strided slice to support both use cases.
tinybvh-rs internally requires positions to be vectors of size 4 and not 3. This is a requirement of the underlying tinybvh library.
Aliased Type
pub struct Positions<'a> { /* private fields */ }